Discovering the human retina and its use for image processing {#tutorial_table_of_content_retina}
============================

-   @subpage tutorial_bioinspired_retina_model

    *Author:* Alexandre Benoit

    Processing regular images

-   @subpage tutorial_bioinspired_retina_illusion

    *Author:* Andrea Merello

    See how to reproduce human eye optical illusions